Enum gitnu::Subcommand
source · pub enum Subcommand {
Status(bool),
Number,
Version,
Unset,
}Expand description
Git sub-command.
Lets Gitnu know what output to expect, and whether or not to read/write cache.
Variants
Status(bool)
Contained value represents if the status command is the regular variant.
gitnu status with no flags gives Status(true).
flags -s, --short, --porcelain gives Status(false).
Number
Gitnu will fetch cache in this state.
Version
A special case where gitnu drops everything and prints its own version next to git’s version.
Unset
Original state.